@@ -22,11 +22,11 @@ VSGDR::StaticData - Static data script support package for SSDT post-deployment
 
 =head1 VERSION
 
-Version 0.37
+Version 0.38
 
 =cut
 
-our $VERSION = '0.37';
+our $VERSION = '0.38';
 
 
 sub databaseName {
@@ -650,8 +650,6 @@ sub generateTestDataScript {
 
 
     my $ra_columns              = columns($dbh,$schema,$table);
-    my $ra_pkcolumns            = pkcolumns($dbh,$quotedSchema,$quotedTable);
-
     croak "${quotedCombinedName} doesn't appear to be a valid table"          unless scalar @{$ra_columns};
     
 
@@ -661,35 +659,16 @@ sub generateTestDataScript {
     my $widest_column_name_len      = max ( map { length ($_->[0]); } @{$ra_columns} ) ;
     my $widest_column_name_padding  = int($widest_column_name_len/4) + 4;
 
-    my $flatcolumnlist          = "" ;
     my $flatvariablelist        = "" ;
     foreach my $l (@{$ra_columns}) {
-        do { local $" = "";   $flatcolumnlist           .= "[$l->[0]]" ; $flatcolumnlist .= ", "} ;
         do { local $" = "";   $flatvariablelist         .= "@"."$l->[0]" ; $flatvariablelist .= ","} ;
     }    
-    $flatcolumnlist             =~ s{ ,\s? \z }{}msx;
     $flatvariablelist           =~ s{ ,\s? \z }{}msx;
 
-    if ( ! scalar @{$ra_pkcolumns} ) {
-        my @pk_ColumnsCheck = () ;
-        foreach my $l (@{$ra_columns}) {
-            my $varlen  = length($l->[0]) ;
-            my $colpadding = $widest_column_name_padding - (int(($varlen)/4));
-            my $varpadding = $widest_column_name_padding - (int(($varlen+1)/4));
-            push @pk_ColumnsCheck , "([$l->[0]]" . "\t"x$varpadding . " = \@$l->[0]" . "\t"x$varpadding . "or ([$l->[0]]". "\t"x$varpadding . " is null and \@$l->[0] ". "\t"x$varpadding . " is null ) ) " ;
-        }
-    }
-    elsif ( scalar @{$ra_pkcolumns} != 1 ) {
-        my @pk_ColumnsCheck = () ;
-        foreach my $l (@{$ra_pkcolumns}) {
-            my $varlen  = length($l->[0]) ;
-            my $colpadding = $widest_column_name_padding - (int(($varlen)/4));
-            my $varpadding = $widest_column_name_padding - (int(($varlen+1)/4));
-            push @pk_ColumnsCheck , "([$l->[0]]" . "\t"x$varpadding . " = \@$l->[0]" . "\t"x$varpadding . "or ([$l->[0]]". "\t"x$varpadding . " is null and \@$l->[0] ". "\t"x$varpadding . " is null ) ) " ;
-        }
-        foreach my $col (@{$ra_columns}) {
-            push @nonKeyColumns, $col unless grep {$_->[0] eq $col->[0] } @{$ra_pkcolumns} ;
-        }
+    foreach my $l (@{$ra_columns}) {
+        my $varlen  = length($l->[0]) ;
+        my $colpadding = $widest_column_name_padding - (int(($varlen)/4));
+        my $varpadding = $widest_column_name_padding - (int(($varlen+1)/4));
     }
 
     my $flatExtractColumnList   = "" ;
@@ -704,8 +683,13 @@ sub generateTestDataScript {
 
     $flatExtractColumnList    =~ s{ ,\s? \z }{}msx;
 
-    my $ra_data = getTestDataForTable($dbh,$quotedCombinedName,$flatExtractColumnList,$sql);
+    my $ra_metadata = describeTestDataForTable($dbh,$sql);
+    my @cols = map { $$_[0] } @$ra_metadata ;
+    my $colList = do { local $" = "," ; "@cols" } ;
+
+    my $ra_data     = getTestDataForTable($dbh,$quotedCombinedName,$flatExtractColumnList,$sql);
     
+#need to over lay tables with columns aprt from those whihc are 'hidden'    
     my @valuesTable     ;
     my $valuesClause    = "values\n\t\t\t";
 
@@ -714,22 +698,19 @@ sub generateTestDataScript {
         my @outVals = undef ;
         for ( my $i = 0; $i < scalar @{$ra_row}; $i++ ) {
             
-            if ( ( $IsColumnNumeric[$i] == 1 ) and ( not ( defined ($ra_row->[$i]) ) ) ) {
+            if ( not ( defined ($ra_row->[$i]) ) ) {
                 $outVals[$i] = 'null' ;  
             }
-            if ( ( $IsColumnNumeric[$i] == 0 ) and ( not ( defined ($ra_row->[$i]) ) ) ) {
-                $outVals[$i] = 'null' ;  
-            }
-            if ( ( $IsColumnNumeric[$i] == 1 ) and (     ( defined ($ra_row->[$i]) ) ) ) {
-                $outVals[$i] = $ra_row->[$i]  ;  
-            }
-            if ( ( $IsColumnNumeric[$i] == 0 ) and (     ( defined ($ra_row->[$i]) ) ) ) {
-                if (${$ra_columns}[$i][1] =~ m{\A(?:date|datetime[2]?|smalldatetime)\z}i) {
+            else {
+                if (${$ra_metadata}[$i][1] =~ m{\A(?:date|datetime[2]?|smalldatetime)\z}i) {
                     $outVals[$i] = "convert(". ${$ra_columns}[$i][1] ."," . $dbh->quote($ra_row->[$i]) . ",120)"   ;
                 }
-                else {
+                elsif ( ${$ra_metadata}[$i][1] =~ m{(?:char|text|date)}i)  {
                     $outVals[$i] = $dbh->quote($ra_row->[$i])  ;  
                 }
+                else {
+                    $outVals[$i] = $ra_row->[$i] ;  
+                }
             }
         }
         push @valuesTable, \@outVals ;
@@ -783,20 +764,20 @@ return <<"EOF";
     select  * 
     from    ( ${valuesClause}
             ) AS vtable 
-    ( $flatcolumnlist)
+    ( ${colList})
     )
     insert  into
             ${quotedCombinedName}
-    (       ${flatcolumnlist}
+    (       ${colList}
     )
-    select  ${flatcolumnlist}
+    select  ${colList}
     from    src ;
     ${set_IDENTITY_INSERT_OFF}
 
 EOF
     }
     else {
-        ${valuesClause} =~ s{\Av alues\n\t\t\t }{ \t\t,\t }msx;
+        ${valuesClause} =~ s{\A values\n\t\t\t }{\t\t,\t}msx;
 return <<"EOF";
 ${valuesClause}
 EOF
@@ -804,6 +785,27 @@ EOF
     }
 }
 
+sub describeTestDataForTable {
+
+    local $_ = undef ;
+    
+    my $dbh          = shift or croak 'no dbh' ;
+    my $sql          = shift or croak 'no sql' ;
+
+    ( my $quoted_sql    = $sql ) =~ s{'}{''}g;
+    
+    my $metadata_sql    = "exec sp_describe_first_result_set N'${quoted_sql}'" ;
+
+    my $sth2            = $dbh->prepare($metadata_sql);
+    my $rs              = $sth2->execute();
+    my $res             = $sth2->fetchall_arrayref() ;
+
+    my @ret_res         = map { [($$_[2],$$_[5],$$_[3],$$_[1])] } @$res;
+
+    return \@ret_res ;
+    
+}
+
 sub getTestDataForTable {
 
     local $_ = undef ;
@@ -814,7 +816,7 @@ sub getTestDataForTable {
     my $sql          = shift or croak 'no sql' ;
 #warn Dumper getCurrentTableDataSQL($combinedName,$pkCol,$cols);
 
-    my $sth2 = $dbh->prepare(getTestDataForTableSQL($sql));
+    my $sth2 = $dbh->prepare($sql);
     my $rs   = $sth2->execute();
     my $res  = $sth2->fetchall_arrayref() ;
 
@@ -822,15 +824,6 @@ sub getTestDataForTable {
     
 }
 
-sub getTestDataForTableSQL {
-    local $_ = undef ;
-    my $sql          = shift or croak 'no sql' ;
-return <<"EOF" ;
-${sql}
-EOF
-}
-
-
 sub getCurrentTableData {
 
     local $_ = undef ;
@@ -1038,6 +1031,8 @@ where   1=1
 and     TABLE_SCHEMA        = ?
 and     TABLE_NAME          = ?
 and     COLUMNPROPERTY(object_id(?+'.'+?) , COLUMN_NAME,'IsComputed') != 1
+--order by ORDINAL_POSITION
+
 EOF
 
 }
